@@ -1,6 +1,8 @@
 #!/bin/sh
 echo `awk '{print $1/1000" MHz"}' /sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq`
 
+echo `awk '/mT/ {memttl = $2}; /mF/ {memfre = $2}; /Bu/ {membff = $2}; $1 == "Cached:" {memcch = $2} END {printf ("%.1f MB\n",(memttl-memfre-membff-memcch)/1024)}' /proc/meminfo`
+
 CONN=$(/sbin/route | awk '/default/ {print $NF}')
 IP="-"
 if [ "$CONN" == "wlan0" ]; then
@@ -8,8 +10,7 @@ if [ "$CONN" == "wlan0" ]; then
 fi
 
 if [ "$CONN" == "gprs0" ]; then
-    IP=$(/sbin/ifconfig gprs0 | awk -F "[: ]" '/Bc/ {print $13}')
+    IP=$(/sbin/ifconfig gprs0 | awk -F "[: ]" '/P-t-P/ {print $13}')
 fi
-echo $IP
+echo -n $IP
 
-echo -n `awk '/mT/ {memttl = $2}; /mF/ {memfre = $2}; /Bu/ {membff = $2}; $1 == "Cached:" {memcch = $2} END {printf ("%.1f MB\n",(memttl-memfre-membff-memcch)/1024)}' /proc/meminfo`
