@@ -25,8 +25,6 @@ LsDateTime::LsDateTime(QString name):
     connect(&m_Timer, SIGNAL(timeout()), this, SLOT(timerSlot()));
     m_Timer.setInterval(500);
     m_Timer.setSingleShot(false);    
-
-    m_StandbyTimer = NULL;
 }
 
 void LsDateTime::applySettings()
@@ -42,14 +40,13 @@ void LsDateTime::applySettings()
     if (m_TimeFormat.contains("s"))
         m_Timer.setInterval(500);
     else
-        m_Timer.setInterval(1000);
+        m_Timer.setInterval(2000);
 
     int backgroundUpdate = getSetting("BackgroundUpdateIntervalSeconds", 0).toInt();
     if (backgroundUpdate > 0){
-        m_StandbyTimer = new QTimer(this);
-        connect(m_StandbyTimer, SIGNAL(timeout()), this, SLOT(timerSlot()));
-        m_StandbyTimer->setInterval(backgroundUpdate * 1000);
-        m_StandbyTimer->setSingleShot(false);
+        connect(&m_StandbyTimer, SIGNAL(timeout()), this, SLOT(timerSlot()));
+        m_StandbyTimer.setInterval(backgroundUpdate * 1000);
+        m_StandbyTimer.setSingleShot(false);
     }
     m_TimeFont = getFontSetting("TimeFont", QFont("", 30, QFont::Normal, false));
 
@@ -99,15 +96,17 @@ void LsDateTime::timerSlot()
 
 void LsDateTime::stopUpdate()
 {
-    m_Timer.stop();
-    if (m_StandbyTimer)
-        m_StandbyTimer->start();
+    if (m_StandbyTimer.interval() > 0)
+        m_StandbyTimer.start();
+
+    if (m_Timer.isActive())
+        m_Timer.stop();
 }
 
 void LsDateTime::startUpdate()
 {
-    if (m_StandbyTimer)
-        m_StandbyTimer->stop();
+    if (m_StandbyTimer.isActive())
+        m_StandbyTimer.stop();
     if (!m_Timer.isActive()){
         timerSlot();
         m_Timer.start();
