@@ -38,7 +38,7 @@ private:
 
     int m_Alignment;
     QTimer m_Timer;
-    QTimer* m_StandbyTimer;
+    QTimer m_StandbyTimer;
     QFont m_TimeFont;
     QFont m_DateFont;
     QColor m_TimeColor;
