@@ -28,12 +28,15 @@ public:
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
                QWidget *widget);
     void applySettings();
+    void startUpdate();
+    void stopUpdate();
 
 private:
     bool m_Connected;
     QString m_Wifi;
     QString m_Gprs;
     QPixmap m_Image;
+    void getNetworkState();
 
 private slots:
     void netStateChanged(QString, QString type, QString state, QString);
